@@ -142,18 +142,18 @@ def get_synchronization_tasks(object_name):
               'condition': lambda Get, GetBool: (Get('update.cl_update_sync_rep') and
                                                  not GetBool('update.cl_update_usetag_set')),
              },
-             {'name': 'update_layman',
-              'message': __("Layman cache update"),
-              'method': Object('update_layman()'),
+             {'name': 'update_rep_list',
+              'message': __("Repository cache update"),
+              'method': Object('update_rep_list()'),
               'condition': lambda Get: (isPkgInstalled(
-                  "app-portage/layman", prefix=Get('cl_chroot_path')) and
+                  "app-eselect/eselect-repository", prefix=Get('cl_chroot_path')) and
                   Get('cl_chroot_path') != "/"),
               'essential': False,
              },
              {'name': 'sync_other_reps',
               'foreach': 'update.cl_update_other_rep_name',
               'message': __("Syncing the {eachvar:capitalize} repository"),
-              'method': Object('syncLaymanRepository(eachvar)'),
+              'method': Object('syncOtherRepository(eachvar)'),
               'condition': lambda GetBool: GetBool('update.cl_update_other_set')
              },
              {'name': 'trim_reps',
