@@ -611,7 +611,7 @@ class VariableClUpdateReposconf(ReadonlyVariable):
     Путь конфигурационного файла repos.conf, содержащего Calculate репозитории
     """
 
-    value_format = "{update.cl_update_reposconf_dir}/calculate.conf"
+    value_format = "{update.cl_update_reposconf_dir}/zz-calculate.conf"
 
 
 class VariableClUpdatePretendSet(Variable):
